=========
Changelog
=========

Version 0.1.6
============

- Added support for TDM Reservation Protocol HTTP headers (https://www.w3.org/2022/tdmrep/#sec-tdm-header). 

Version 0.1.5
=============

- Added support for python 3.7.

Version 0.1.4
=============

- Increasing formats supported by HTTP X-Robots-Tag header.

Version 0.1.2
=============

- Resolved minor linting issues.

Version 0.1.1
=============

- Pinning some dependencies for a more predictable build.

Version 0.1.0
=============

- Initial commit. Welcome!
